``zope.componentvocabulary``
============================

.. image:: https://github.com/zopefoundation/zope.componentvocabulary/actions/workflows/tests.yml/badge.svg
        :target: https://github.com/zopefoundation/zope.componentvocabulary/actions/workflows/tests.yml

.. image:: https://coveralls.io/repos/github/zopefoundation/zope.componentvocabulary/badge.svg?branch=master
        :target: https://coveralls.io/github/zopefoundation/zope.componentvocabulary?branch=master



This package contains various vocabularies.
